"""
PyPath

Python library for pathology image analysis
"""

__version__ = '0.1.0'
__author__  = 'Attasuntorn Traisuwan'


# Bring in subpackages